OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Non é posíbel escribir no directorio «config»!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Polo xeral, isto pode ser fixado para permitirlle ao servidor web acceso de escritura  ao directorio «config»",
    "See %s" : "Vexa %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ou, se prefire manter o ficheiro «config.php» como de só lectura, marque a opción «config_is_read_only» como «true» nel.",
    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Polo xeral, isto pode ser fixado para permitirlle ao servidor web acceso de escritura  ao directorio «config». Vexa %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ou, se prefire manter o ficheiro «config.php» como de só lectura, marque a opción «config_is_read_only» como «true» nel. Vexa %s",
    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Os ficheiros da aplicación %1$s non foron substituídos correctamente. Asegúrese que é unha versión compatíbel co servidor.",
    "Sample configuration detected" : "Detectouse a configuración de exemplo",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Detectouse que foi copiada a configuración de exemplo. Isto pode rachar a súa instalación e non é compatíbel. Lea a documentación antes de facer cambios en config.php",
    "%1$s and %2$s" : "%1$s e %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s e %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s e %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s e %5$s",
    "Education Edition" : "Edición para educación",
    "Enterprise bundle" : "Paquete empresarial",
    "Groupware bundle" : "Paquete de software colaborativo",
    "Social sharing bundle" : "Paquete para compartir en redes sociais",
    "PHP %s or higher is required." : "Requirese PHP %s ou superior.",
    "PHP with a version lower than %s is required." : "Requírese PHP cunha versión inferior a %s.",
    "%sbit or higher PHP required." : "Requirese PHP para %sbit ou superior.",
    "Following databases are supported: %s" : "Admítense as seguintes bases de datos: %s",
    "The command line tool %s could not be found" : "Non foi posíbel atopar a ferramenta de liña de ordes %s",
    "The library %s is not available." : "Non está dispoñíbel a biblioteca %s.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Requírese a biblioteca %1$s cunha versión superior a %2$s - dispoñíbel a versión %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Requírese a biblioteca %1$s cunha versión inferior a %2$s - dispoñíbel a versión %3$s.",
    "Following platforms are supported: %s" : "Admítense as seguintes plataformas: %s",
    "Server version %s or higher is required." : "Requírese a versión %s ou superior do servidor.",
    "Server version %s or lower is required." : "Requírese a versión %s ou inferior do servidor.",
    "Logged in user must be an admin or sub admin" : "O usuario rexistrado debe ser un administrador ou subadministrador",
    "Logged in user must be an admin" : "O usuario rexistrado debe ser un administrador",
    "Wiping of device %s has started" : "Iniciouse a limpeza do dispositivo %s",
    "Wiping of device »%s« has started" : "Iniciouse a limpeza do dispositivo «%s»",
    "»%s« started remote wipe" : "«%s» iniciou a limpeza remota",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "O dispositivo ou aplicación «%s» iniciou o proceso remoto de limpeza. Recibirá outro correo  cando remate o proceso",
    "Wiping of device %s has finished" : "Rematou a limpeza do dispositivo %s",
    "Wiping of device »%s« has finished" : "Rematou a limpeza do dispositivo «%s»",
    "»%s« finished remote wipe" : "«%s» rematou a limpeza remota",
    "Device or application »%s« has finished the remote wipe process." : "O dispositivo ou aplicación «%s» rematou o proceso remoto de limpeza.",
    "Remote wipe started" : "Iniciouse a limpeza remota",
    "A remote wipe was started on device %s" : "Iniciouse unha limpeza remota no dispositivo %s",
    "Remote wipe finished" : "Rematou a limpeza remota",
    "The remote wipe on %s has finished" : "A limpeza remota en %s rematou",
    "Authentication" : "Autenticación",
    "Unknown filetype" : "Tipo de ficheiro descoñecido",
    "Invalid image" : "Imaxe incorrecta",
    "Avatar image is not square" : "A imaxe do avatar non é un cadrado",
    "today" : "hoxe",
    "tomorrow" : "mañá",
    "yesterday" : "onte",
    "_in %n day_::_in %n days_" : ["nun día","en %n días"],
    "_%n day ago_::_%n days ago_" : ["hai %n día","hai %n días"],
    "next month" : "o mes que ven",
    "last month" : "o mes pasado",
    "_in %n month_::_in %n months_" : ["nun mes","en %n meses"],
    "_%n month ago_::_%n months ago_" : ["hai %n mes","hai %n meses"],
    "next year" : "o ano que ven",
    "last year" : "o ano pasado",
    "_in %n year_::_in %n years_" : ["nun ano","en %n anos"],
    "_%n year ago_::_%n years ago_" : ["hai %n ano","hai %n anos"],
    "_in %n hour_::_in %n hours_" : ["nunha hora","en %n horas"],
    "_%n hour ago_::_%n hours ago_" : ["hai %n hora","hai %n horas"],
    "_in %n minute_::_in %n minutes_" : ["nun minuto","en %n minutos"],
    "_%n minute ago_::_%n minutes ago_" : ["hai %n minuto","hai %n minutos"],
    "in a few seconds" : "en poucos segundos",
    "seconds ago" : "segundos atrás",
    "Empty file" : "Ficheiro baleiro",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Non existe o módulo co ID: %s. Actíveo nos axustes das aplicacións ou contacte co administrador.",
    "File name is a reserved word" : "O nome de ficheiro é unha palabra reservada",
    "File name contains at least one invalid character" : "O nome de ficheiro contén algún carácter incorrecto",
    "File name is too long" : "O nome de ficheiro é longo de máis",
    "Dot files are not allowed" : "Non se admiten os ficheiros con punto",
    "Empty filename is not allowed" : "Non está permitido deixar baleiro o nome de ficheiro",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Non é posíbel instalar a aplicación «%s» por mor de non poder ler o ficheiro appinfo.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Non é posíbel instalar a aplicación «%s» por mor de non ser compatíbel con esta versión do servidor.",
    "__language_name__" : "Galego",
    "This is an automatically sent email, please do not reply." : "Este é un correo enviado automaticamente, non responda.",
    "Help" : "Axuda",
    "Apps" : "Aplicacións",
    "Settings" : "Axustes",
    "Log out" : "Saír",
    "Users" : "Usuarios",
    "Unknown user" : "Usuario descoñecido",
    "Overview" : "Vista xeral",
    "Basic settings" : "Axustes básicos",
    "Sharing" : "Compartindo",
    "Security" : "Seguridade",
    "Groupware" : "Software colaborativo",
    "Additional settings" : "Axustes adicionais",
    "Personal info" : "Información persoal",
    "Mobile & desktop" : "Móbil e escritorio",
    "%s enter the database username and name." : "%s introduza o nome de usuario e o nome da base de datos",
    "%s enter the database username." : "%s introduza o nome de usuario da base de datos",
    "%s enter the database name." : "%s introduza o nome da base de datos",
    "%s you may not use dots in the database name" : "%s non se poden empregar puntos na base de datos",
    "Oracle connection could not be established" : "Non foi posíbel estabelecer a conexión con Oracle",
    "Oracle username and/or password not valid" : "O nome de usuario e/ou contrasinal de Oracle é incorrecto",
    "PostgreSQL username and/or password not valid" : "Nome de usuario e/ou contrasinal de PostgreSQL incorrecto",
    "You need to enter details of an existing account." : "Debe inserir os detalles dunha conta existente.",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X non é compatíbel e %s non funcionará correctamente nesta plataforma. Utilíceo baixo a  súa responsabilidade!",
    "For the best results, please consider using a GNU/Linux server instead." : "Para obter mellores resultados, considere o emprego dun servidor GNU/Linux no seu canto.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Semella que esta instancia de %s está a funcionar nun contorno PHP de 32 bisst e o open_basedir foi configurado no php.ini. Isto provocará problemas con ficheiros maiores de 4 GB e está absolutamente desaconsellado.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Retire o axuste de open_basedir no php.ini ou cambie a PHP de 64 bits.",
    "Set an admin username." : "Estabeleza un nome de usuario administrador",
    "Set an admin password." : "Estabeleza un contrasinal de administrador",
    "Can't create or write into the data directory %s" : "Non é posíbel crear ou escribir o directorio «data» %s",
    "Invalid Federated Cloud ID" : "ID de nube federada incorrecto",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "A infraestrutura de compartición %s ten que implementar a interface OCP\\Share_Backend",
    "Sharing backend %s not found" : "Non se atopou a infraestrutura de compartición %s",
    "Sharing backend for %s not found" : "Non se atopou a infraestrutura de compartición para %s",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s compartiu «%2$s» con vostede e quere engadir:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s compartiu «%2$s» con vostede e quere engadir",
    "»%s« added a note to a file shared with you" : "«%s» engadiu unha nota a un ficheiro compartido con vostede",
    "Open »%s«" : "Abrir «%s»",
    "%1$s via %2$s" : "%1$s mediante %2$s",
    "You are not allowed to share %s" : "Non ten permiso para compartir %s",
    "Can’t increase permissions of %s" : "Non é posíbel aumentar os permisos de %s",
    "Files can’t be shared with delete permissions" : "Non é posíbel compartir ficheiros con permisos de eliminación",
    "Files can’t be shared with create permissions" : "Non é posíbel compartir ficheiros con permisos de creación",
    "Expiration date is in the past" : "Xa pasou a data de caducidade",
    "Can’t set expiration date more than %s days in the future" : "Non é posíbel estabelecer a data de caducidade máis alo de %s días no futuro",
    "%1$s shared »%2$s« with you" : "%1$s compartiu «%2$s» con vostede",
    "%1$s shared »%2$s« with you." : "%1$s compartiu «%2$s» con vostede.",
    "Click the button below to open it." : "Prema no botón de embaixo para abrilo.",
    "The requested share does not exist anymore" : "O recurso compartido solicitado xa non existe",
    "Could not find category \"%s\"" : "Non foi posíbel atopar a categoría «%s»",
    "Sunday" : "domingo",
    "Monday" : "luns",
    "Tuesday" : "martes",
    "Wednesday" : "mércores",
    "Thursday" : "xoves",
    "Friday" : "venres",
    "Saturday" : "sábado",
    "Sun." : "dom.",
    "Mon." : "lun.",
    "Tue." : "mar.",
    "Wed." : "mér.",
    "Thu." : "xov.",
    "Fri." : "ven.",
    "Sat." : "sáb.",
    "Su" : "do",
    "Mo" : "lu",
    "Tu" : "ma",
    "We" : "mé",
    "Th" : "xo",
    "Fr" : "ve",
    "Sa" : "sá",
    "January" : "xaneiro",
    "February" : "febreiro",
    "March" : "marzo",
    "April" : "abril",
    "May" : "maio",
    "June" : "xuño",
    "July" : "xullo",
    "August" : "agosto",
    "September" : "setembro",
    "October" : "outubro",
    "November" : "novembro",
    "December" : "decembro",
    "Jan." : "xan.",
    "Feb." : "feb.",
    "Mar." : "mar.",
    "Apr." : "abr.",
    "May." : "mai.",
    "Jun." : "xuñ.",
    "Jul." : "xul.",
    "Aug." : "ago.",
    "Sep." : "set.",
    "Oct." : "out.",
    "Nov." : "nov.",
    "Dec." : "dec.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Só os seguintes caracteres están permitidos nos nomes de usuario: «a-z», «A-Z», «0-9» e «_.@-'»",
    "A valid username must be provided" : "Debe fornecer un nome de usuario correcto",
    "Username contains whitespace at the beginning or at the end" : "O nome de usuario contén un espazo en branco no inicio ou no final",
    "Username must not consist of dots only" : "O nome de usuario non debe consistir só de puntos",
    "Username is invalid because files already exist for this user" : "O nome de usuario non é válido porque xa existen ficheiros para este usuario",
    "A valid password must be provided" : "Debe fornecer un contrasinal",
    "The username is already being used" : "Este nome de usuario xa está a ser usado",
    "Could not create user" : "Non foi posíbel crear o usuario",
    "User disabled" : "Usuario desactivado",
    "Login canceled by app" : "Acceso cancelado pola aplicación",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Non é posíbel instalar a aplicación «%1$s» por mor de non cumprirse as dependencias: %2$s",
    "a safe home for all your data" : "un lugar seguro para todos os seus datos",
    "File is currently busy, please try again later" : "O ficheiro está ocupado neste momento, ténteo máis tarde.",
    "Can't read file" : "Non é posíbel ler o ficheiro",
    "Application is not enabled" : "A aplicación non está activada",
    "Authentication error" : "Produciuse un erro de autenticación",
    "Token expired. Please reload page." : "Marca caducada. Recargue a páxina.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Non hai controladores de base de datos (sqlite, mysql, ou postgresql) instalados.",
    "Cannot write into \"config\" directory" : "Non é posíbel escribir no directorio «config»",
    "Cannot write into \"apps\" directory" : "Non é posíbel escribir no directorio «apps»",
    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "Polo xeral, isto pódese solucionar dándolle ao servidor web acceso de escritura  ao directorio das aplicacións ou desactivando a tenda de aplicacións no ficheiro de configuración. Vexa %s",
    "Cannot create \"data\" directory" : "Non é posíbel crear o directorio «data»",
    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Polo xeral, isto pódese solucionar dándolle ao servidor web acceso de escritura  ao directorio raíz. Vexa %s.",
    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Polo xeral, pódense corrixir os permisos dándolle ao servidor web acceso de escritura  ao directorio raíz. Vexa %s.",
    "Setting locale to %s failed" : "Fallou o axuste da configuración local a %s",
    "Please install one of these locales on your system and restart your webserver." : "Instale unha destas configuracións locais no seu sistema e reinicie o servidor web.",
    "Please ask your server administrator to install the module." : "Pregúntelle ao administrador do servidor pola instalación do módulo.",
    "PHP module %s not installed." : "O módulo PHP %s non está instalado.",
    "PHP setting \"%s\" is not set to \"%s\"." : "O axuste de PHP «%s» non está estabelecido a «%s».",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Cambiar este axuste no ficheiro php.ini fará que Nextcloud funcione de novo",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload está estabelecido a «%s» no canto do valor «0» agardado",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Para arranxar este incidente, estabeleza <code>mbstring.func_overload</code> a <code>0</code> no ficheiro php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Requírese cando menos libxml2 2.7.0. Actualmente esta instalado %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Para arranxar este incidente, actualice a versión de libxml2 e reinicie o servidor web. ",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Semella que PHP foi configurado para quitar bloques de documentos en liña. Isto fará que varias aplicacións sexan inaccesíbeis.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isto probabelmente se debe unha caché/acelerador como Zend OPcache ou eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Instaláronse os módulos de PHP, mais aínda aparecen listados como perdidos?",
    "Please ask your server administrator to restart the web server." : "Pregúntelle ao administrador do servidor polo reinicio do servidor web..",
    "PostgreSQL >= 9 required" : "Requírese PostgreSQL >= 9",
    "Please upgrade your database version" : "Anove a versión da súa base de datos",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Cambie os permisos a 0770 para que o directorio non poida ser listado por outros usuarios.",
    "Your data directory is readable by other users" : "O se directorio de datos é lexíbel por outros usuarios",
    "Your data directory must be an absolute path" : "O seu directorio de datos debe ser unha ruta absoluta",
    "Check the value of \"datadirectory\" in your configuration" : "Comprobe o valor de «datadirectory» na configuración",
    "Your data directory is invalid" : "O seu directorio de datos non é correcto",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Asegúrese de que existe un ficheiro chamado «.ocdata» na raíz do directorio de datos.",
    "Action \"%s\" not supported or implemented." : "A acción «%s» non está admitida ou implementada.",
    "Authentication failed, wrong token or provider ID given" : "Produciuse un fallo de autenticación. Deuse unha marca ou un ID de provedor erróneos.",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Faltan parámetros para completar a solicitude. Parámetros que faltan: «%s»",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "O ID «%1$s» xa está a ser usado polo provedor da nube federada «%2$s»",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "O  provedor de nube federada co ID «%s» non existe.",
    "Could not obtain lock type %d on \"%s\"." : "Non foi posíbel obter un bloqueo do tipo %d en «%s».",
    "Storage unauthorized. %s" : "Almacenamento non autorizado. %s",
    "Storage incomplete configuration. %s" : "Configuración incompleta do almacenamento. %s",
    "Storage connection error. %s" : "Produciuse un erro na conexión ao almacenamento. %s",
    "Storage is temporarily not available" : "O almacenamento non está dispoñíbel temporalmente",
    "Storage connection timeout. %s" : "Esgotouse o tempo de conexión co almacenamento. %s",
    "Create" : "Crear",
    "Change" : "Cambiar",
    "Delete" : "Eliminar",
    "Share" : "Compartir",
    "Unlimited" : "Sen límites",
    "Verifying" : "Verificando",
    "Verifying …" : "Verificando…",
    "Verify" : "Verificar",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Fallou a compartición de %s, xa que a infraestrutura non permite accións do tipo %i",
    "Sharing %s failed, because the file does not exist" : "Fallou a compartición de %s, o ficheiro non existe",
    "Sharing %s failed, because you can not share with yourself" : "Fallou a compartición de %s por mor de que non pode compartir con vostede mesmo",
    "Sharing %1$s failed, because the user %2$s does not exist" : "Fallou a compartición de %1$s, o usuario %2$s non existe",
    "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "Fallou a compartición de %1$s, o usuario %2$s non é membro en ningún grupo no que sexa membro %3$s",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "Produciuse un fallou na compartición de %1$s, este elemento xa está compartido con %2$s",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Fallou a compartición de %1$s por mor de que este elemento xa foi compartido co usuario %2$s",
    "Sharing %1$s failed, because the group %2$s does not exist" : "Fallou a compartición de %1$s, o grupo %2$s non existe",
    "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "Fallou a compartición de %1$s, %2$s non é membro do grupo %3$s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Ten que fornecer un contrasinal para a ligazón pública, só se permiten ligazóns protexidas",
    "Sharing %s failed, because sharing with links is not allowed" : "Fallou a compartición de %s, non está permitido compartir con ligazóns",
    "Not allowed to create a federated share with the same user" : "Non está permitido crear un compartido federado co mesmo usuario",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "Fallou a compartición de %1$s, non foi posíbel atopar %2$s,é probábel que o servidor non estea accesíbel.",
    "Share type %1$s is not valid for %2$s" : "Non se admite a compartición do tipo %1$s para %2$s",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Non é posíbel estabelecer a data de caducidade. As comparticións non poden caducar máis aló de %s após de seren compartidas",
    "Cannot set expiration date. Expiration date is in the past" : "Non é posíbel estabelecer a data de caducidade. A data de caducidade está no pasado.",
    "Sharing failed, because the user %s is the original sharer" : "Fallou a compartición, por mor de que o usuario %s é o compartidor orixinal",
    "Sharing %1$s failed, because the permissions exceed permissions granted to %2$s" : "Fallou a compartición de %1$s, os permisos superan os permisos concedidos a %2$s",
    "Sharing %s failed, because resharing is not allowed" : "Fallou a compartición de %s, non está permitido repetir a compartción",
    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Fallou a compartición de %1$s, a infraestrutura de compartición para %2$s non foi quen de atopar a orixe",
    "Sharing %s failed, because the file could not be found in the file cache" : "Fallou a compartición de %s, non foi posíbel atopar o ficheiro na caché de ficheiros"
},
"nplurals=2; plural=(n != 1);");
